**Describe the issue**
A clear and concise description of what the issue is.

**To Reproduce**
What command line were you trying to run?

```bash
ocrmypdf  ...arguments... input.pdf output.pdf
```

**Example file**
Please include an example *input* PDF (or image). You could also try to use of the files in ``tests/resources/`` to illustrate your issue.

Please check any or all that apply about the example file:

- [ ] This is the input file
- [ ] The file contains no personal or confidential information

Please do *not* submit files with confidential information. At your option you may encrypt files for OCRmyPDF's author only.

Issues submitted without an example input file are less likely to be resolved. The output file is generally not helpful.

**Expected behavior**
A clear and concise description of what you expected to happen. Include screenshots if applicable.

**System:**

- OS: [e.g. Linux, macOS]
- OCRmyPDF Version: [e.g. v10.3.0]

**Additional context**
Add any other context about the problem here.
